==> smartgwt-4.1p.zip: com/smartgwt/logicalstructure/widgets/DateChooserLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class DateChooserLogicalStructure extends VLayoutLogicalStructure {
    public String alternateStyleSuffix;
    public String alternateWeekStyles;
    public String applyButtonTitle;
    public String baseBottomButtonStyle;
    public String baseButtonStyle;
    public String baseFiscalYearStyle;
    public String baseNavButtonStyle;
    public String baseWeekdayStyle;
    public String baseWeekendStyle;
    public String baseWeekStyle;
    public String cancelButtonTitle;
    public String closeOnDateClick;
    public String closeOnEscapeKeypress;
    public String dayNameLength;
    public String[] disabledDates;
    public String disabledWeekdayStyle;
    public String disabledWeekendStyle;
    public String disableWeekends;
    public String endYear;
    public String firstDayOfWeek;
    public String fiscalYearFieldTitle;
    public String fiscalYearHeaderStyle;
    public String headerHeight;
    public String headerStyle;
    public String monthMenuStyle;
    public String navigationLayoutHeight;
    public String nextMonthIcon;
    public String nextMonthIconHeight;
    public String nextMonthIconRTL;
    public String nextMonthIconWidth;
    public String nextYearIcon;
    public String nextYearIconHeight;
    public String nextYearIconRTL;
    public String nextYearIconWidth;
    public String prevMonthIcon;
    public String prevMonthIconHeight;
    public String prevMonthIconRTL;
    public String prevMonthIconWidth;
    public String prevYearIcon;
    public String prevYearIconHeight;
    public String prevYearIconRTL;
    public String prevYearIconWidth;
    public String selectedWeekStyle;
    public String showApplyButton;
    public String showCancelButton;
    public String showFiscalYearChooser;
    public String showSecondItem;
    public String showTimeItem;
    public String showTodayButton;
    public String showWeekChooser;
    public String showWeekends;
    public String skinImgDir;
    public String startYear;
    public String timeItemProperties;
    public String timeItemTitle;
    public String todayButtonHeight;
    public String todayButtonTitle;
    public String use24HourTime;
    public String useFirstDayOfFiscalWeek;
    public String weekendHeaderStyle;
    public String weekFieldTitle;
    public String weekHeaderStyle;
    public String weekMenuStyle;
    public String yearMenuStyle;
}

==> smartgwt-14.1p.zip: com/smartgwt/logicalstructure/widgets/DateChooserLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.util.tour.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class DateChooserLogicalStructure extends VLayoutLogicalStructure {
    public String alternateStyleSuffix;
    public String alternateWeekStyles;
    public String applyButtonTitle;
    public String baseBottomButtonStyle;
    public String baseButtonStyle;
    public String baseFiscalYearStyle;
    public String baseNavButtonStyle;
    public String baseWeekdayStyle;
    public String baseWeekendStyle;
    public String baseWeekStyle;
    public String[] buttonLayoutControls;
    public String cancelButtonTitle;
    public String closeOnDateClick;
    public String closeOnEscapeKeypress;
    public String dayNameLength;
    public String[] disabledDates;
    public String disabledWeekdayStyle;
    public String disabledWeekendStyle;
    public String disableWeekends;
    public String endDate;
    public String endYear;
    public String endYearRange;
    public String firstDayOfWeek;
    public String fiscalYearFieldTitle;
    public String fiscalYearHeaderStyle;
    public String headerHeight;
    public String headerStyle;
    public String menuItemStyle;
    public String monthMenuStyle;
    public String navigationButtonHeight;
    public String navigationLayoutHeight;
    public String nextMonthButtonAriaLabel;
    public String nextMonthIcon;
    public String nextMonthIconHeight;
    public String nextMonthIconRTL;
    public String nextMonthIconWidth;
    public String nextYearButtonAriaLabel;
    public String nextYearIcon;
    public String nextYearIconHeight;
    public String nextYearIconRTL;
    public String nextYearIconWidth;
    public String previousMonthButtonAriaLabel;
    public String previousYearButtonAriaLabel;
    public String prevMonthIcon;
    public String prevMonthIconHeight;
    public String prevMonthIconRTL;
    public String prevMonthIconWidth;
    public String prevYearIcon;
    public String prevYearIconHeight;
    public String prevYearIconRTL;
    public String prevYearIconWidth;
    public String selectedWeekStyle;
    public String showApplyButton;
    public String showCancelButton;
    public String showFiscalYearChooser;
    public String showSecondItem;
    public String showTimeItem;
    public String showTodayButton;
    public String showWeekChooser;
    public String showWeekends;
    public String skinImgDir;
    public String startDate;
    public String startYear;
    public String startYearRange;
    public String styleWeekends;
    public String timeItemTitle;
    public String todayButtonHeight;
    public String todayButtonTitle;
    public String use24HourTime;
    public String useFirstDayOfFiscalWeek;
    public String[] weekendDays;
    public String weekendHeaderStyle;
    public String weekFieldTitle;
    public String weekHeaderStyle;
    public String weekMenuStyle;
    public String yearMenuStyle;
}
